#!/usr/bin/env python
# encoding: utf-8
#
# This file is part of ckanext-status
# Created by the Natural History Museum in London, UK

from ckan.plugins import toolkit
import markdown


def status_enable_html():
    return toolkit.asbool(toolkit.config.get('ckanext.status.enable_html', True))


def status_get_message():
    """
    Retrieve status message from config file.

    :returns: status message specified in config file (or None if not specified)
    :rtype: string
    """

    status_message = toolkit.config.get('ckanext.status.message', None)
    if status_message and status_enable_html():
        status_message = markdown.markdown(status_message)
    return status_message



#!/usr/bin/env python
# encoding: utf-8
#
# This file is part of ckanext-status
# Created by the Natural History Museum in London, UK

from ckan.plugins import SingletonPlugin, implements, interfaces, toolkit
from ckanext.status.lib.helpers import status_get_message, status_enable_html


class StatusPlugin(SingletonPlugin):
    """
    Provides status bar banner at the top of pages.
    """

    implements(interfaces.IConfigurer, inherit=True)
    implements(interfaces.ITemplateHelpers)

    # IConfigurer
    def update_config(self, config):
        toolkit.add_template_directory(config, 'theme/templates')
        toolkit.add_resource('theme/assets', 'ckanext-status')

    # IConfigurer
    def update_config_schema(self, schema):
        ignore_missing = toolkit.get_validator('ignore_missing')
        schema.update(
            {
                'ckanext.status.message': [ignore_missing, str],
            }
        )
        return schema

    # ITemplateHelpers
    def get_helpers(self):
        return {
            'status_get_message': status_get_message,
            'status_enable_html': status_enable_html,
        }



#!/usr/bin/env python
# encoding: utf-8
#
# This file is part of ckanext-status
# Created by the Natural History Museum in London, UK
import pytest
from ckan.plugins import toolkit
from ckanext.status.lib.helpers import status_get_message
import markdown

TEST_MESSAGE = 'this is a test message'
MARKDOWN_TEST_MESSAGE = '_this_ is a test **message**'
HTML_TEST_MESSAGE = '<p><em>this</em> is a test <strong>message</strong></p>'


@pytest.mark.filterwarnings('ignore::sqlalchemy.exc.SADeprecationWarning')
@pytest.mark.ckan_config('ckan.plugins', 'status')
@pytest.mark.ckan_config('ckanext.status.message', TEST_MESSAGE)
@pytest.mark.ckan_config('ckanext.status.enable_html', False)
@pytest.mark.usefixtures('with_plugins')
def test_helper_gets_message_when_present():
    message = status_get_message()
    assert message == TEST_MESSAGE


@pytest.mark.filterwarnings('ignore::sqlalchemy.exc.SADeprecationWarning')
@pytest.mark.ckan_config('ckan.plugins', 'status')
@pytest.mark.ckan_config('ckanext.status.message', MARKDOWN_TEST_MESSAGE)
@pytest.mark.ckan_config('ckanext.status.enable_html', True)
@pytest.mark.usefixtures('with_plugins')
def test_helper_parses_markdown_message():
    message = status_get_message()
    assert message == HTML_TEST_MESSAGE


@pytest.mark.filterwarnings('ignore::sqlalchemy.exc.SADeprecationWarning')
@pytest.mark.ckan_config('ckan.plugins', 'status')
@pytest.mark.usefixtures('with_plugins')
def test_helper_gets_none_when_absent():
    # sanity check
    assert 'ckanext.status.message' not in toolkit.config
    message = status_get_message()
    assert message is None
